ILDREAFormat: Survival and Recurrent Events Analysis Data Formatting for...

Description Usage Arguments Examples

View source: R/SurvivalDataFormat.R

Description

This function prepares the data for analysis of effects on time to next use for intensive longitudinal EMA data.

Usage

1
ILDREAFormat(directory)

Arguments

directory

The directory where the EMA dataframe is available.

Examples

1

lalondetl/ILD documentation built on May 28, 2019, 9:50 a.m.